==> haskell-microlens-aeson-2.3.0.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.3.0.1
id: microlens-aeson-2.3.0.1-9z78yM1Eu4y5cASp36ztY6
key: microlens-aeson-2.3.0.1-9z78yM1Eu4y5cASp36ztY6
license: MIT
copyright: Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colingw@gmail.com>
author: Colin Woodbury
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
abi: 6d1470120dec7d937c439d361b8e91eb
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal Paths_microlens_aeson
import-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-aeson-2.3.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-aeson-2.3.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microlens-aeson-2.3.0.1
hs-libraries: HSmicrolens-aeson-2.3.0.1-9z78yM1Eu4y5cASp36ztY6
depends:
    aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-aeson-2.3.0.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.3.0.2
id: microlens-aeson-2.3.0.2-7w9Zxq4JqJ91gO8H7MIABg
key: microlens-aeson-2.3.0.2-7w9Zxq4JqJ91gO8H7MIABg
license: MIT
copyright: Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colin@fosskers.ca>
author: Colin Woodbury
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
abi: f9161525ef3ec57cb8dbfa86aa592d30
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-aeson-2.3.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-aeson-2.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microlens-aeson-2.3.0.2
hs-libraries: HSmicrolens-aeson-2.3.0.2-7w9Zxq4JqJ91gO8H7MIABg
depends:
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L
    attoparsec-0.13.2.2-IaNz9bz10S32KGLwZomjal base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
